@@ -40,7 +40,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.12.18"
+__version__ = "1.13.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Wiznet5k.git"
 
 from random import randint
@@ -187,7 +187,8 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
 
         # attempt to initialize the module
         self._ch_base_msb = 0
-        assert self._w5xxx_init() == 1, "Failed to initialize WIZnet module."
+        if self._w5xxx_init() != 1:
+            raise RuntimeError("Failed to initialize WIZnet module.")
         # Set MAC address
         self.mac_address = mac
         self.src_port = 0
@@ -214,7 +215,8 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
             ret = self.set_dhcp(hostname, dhcp_timeout)
             if ret != 0:
                 self._dhcp_client = None
-            assert ret == 0, "Failed to configure DHCP Server!"
+            if ret != 0:
+                raise RuntimeError("Failed to configure DHCP Server!")
 
     def set_dhcp(
         self, hostname: Optional[str] = None, response_timeout: float = 30
@@ -272,7 +274,8 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         ret = _dns_client.gethostbyname(hostname)
         if self._debug:
             print("* Resolved IP: ", ret)
-        assert ret != -1, "Failed to resolve hostname!"
+        if ret == -1:
+            raise RuntimeError("Failed to resolve hostname!")
         return ret
 
     @property
@@ -626,7 +629,8 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
                     socket_num, sock_type
                 )
             )
-        assert socket_num <= self.max_sockets, "Provided socket exceeds max_sockets."
+        if socket_num > self.max_sockets:
+            raise ValueError("Provided socket exceeds max_sockets.")
 
         res = self._get_rx_rcv_size(socket_num)
 
@@ -679,7 +683,8 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         :param int conn_mode: The connection mode. Use SNMR_TCP for TCP or SNMR_UDP for UDP,
             defaults to SNMR_TCP.
         """
-        assert self.link_status, "Ethernet cable disconnected!"
+        if not self.link_status:
+            raise ConnectionError("Ethernet cable disconnected!")
         if self._debug:
             print(
                 "* w5k socket connect, protocol={}, port={}, ip={}".format(
@@ -689,7 +694,7 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         # initialize a socket and set the mode
         res = self.socket_open(socket_num, conn_mode=conn_mode)
         if res == 1:
-            raise RuntimeError("Failed to initialize a connection with the socket.")
+            raise ConnectionError("Failed to initialize a connection with the socket.")
 
         # set socket destination IP and port
         self._write_sndipr(socket_num, dest)
@@ -703,7 +708,7 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
                 if self._debug:
                     print("SN_SR:", self.socket_status(socket_num)[0])
                 if self.socket_status(socket_num)[0] == SNSR_SOCK_CLOSED:
-                    raise RuntimeError("Failed to establish connection.")
+                    raise ConnectionError("Failed to establish connection.")
         elif conn_mode == SNMR_UDP:
             self.udp_datasize[socket_num] = 0
         return 1
@@ -747,7 +752,8 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         :param int conn_mode: Connection mode SNMR_TCP for TCP or SNMR_UDP for
             UDP, defaults to SNMR_TCP.
         """
-        assert self.link_status, "Ethernet cable disconnected!"
+        if not self.link_status:
+            raise ConnectionError("Ethernet cable disconnected!")
         if self._debug:
             print(
                 "* Listening on port={}, ip={}".format(
@@ -807,7 +813,8 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
             UDP, defaults to SNMR_TCP.
         :return int: 1 if the socket was opened, 0 if not.
         """
-        assert self.link_status, "Ethernet cable disconnected!"
+        if not self.link_status:
+            raise ConnectionError("Ethernet cable disconnected!")
         if self._debug:
             print("*** Opening socket %d" % socket_num)
         status = self._read_snsr(socket_num)[0]
@@ -839,10 +846,8 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
             # open socket
             self._write_sncr(socket_num, CMD_SOCK_OPEN)
             self._read_sncr(socket_num)
-            assert (
-                self._read_snsr((socket_num))[0] == 0x13
-                or self._read_snsr((socket_num))[0] == 0x22
-            ), "Could not open socket in TCP or UDP mode."
+            if self._read_snsr((socket_num))[0] not in [0x13, 0x22]:
+                raise RuntimeError("Could not open socket in TCP or UDP mode.")
             return 0
         return 1
 
@@ -868,7 +873,7 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         self._write_sncr(socket_num, CMD_SOCK_DISCON)
         self._read_sncr(socket_num)
 
-    def socket_read(
+    def socket_read(  # pylint: disable=too-many-branches
         self, socket_num: int, length: int
     ) -> Tuple[int, Union[int, bytearray]]:
         """
@@ -882,8 +887,11 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
             was unsuccessful then both items equal an error code, 0 for no data waiting and -1
             for no connection to the socket.
         """
-        assert self.link_status, "Ethernet cable disconnected!"
-        assert socket_num <= self.max_sockets, "Provided socket exceeds max_sockets."
+
+        if not self.link_status:
+            raise ConnectionError("Ethernet cable disconnected!")
+        if socket_num > self.max_sockets:
+            raise ValueError("Provided socket exceeds max_sockets.")
 
         # Check if there is data available on the socket
         ret = self._get_rx_rcv_size(socket_num)
@@ -976,7 +984,8 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
 
         :return int: The number of bytes written to the buffer.
         """
-        assert self.link_status, "Ethernet cable disconnected!"
+        if not self.link_status:
+            raise ConnectionError("Ethernet cable disconnected!")
         assert socket_num <= self.max_sockets, "Provided socket exceeds max_sockets."
         status = 0
         ret = 0
