@@ -27,6 +27,15 @@ https://www.python.org/dev/peps/pep-0333/
 * Author(s): Matt Costi, Patrick Van Oosterwijck
 """
 # pylint: disable=no-name-in-module
+from __future__ import annotations
+
+try:
+    from typing import TYPE_CHECKING, Optional, List, Tuple, Dict
+
+    if TYPE_CHECKING:
+        from adafruit_wiznet5k.adafruit_wiznet5k import WIZNET5K
+except ImportError:
+    pass
 
 import io
 import gc
@@ -34,11 +43,15 @@ from micropython import const
 import adafruit_wiznet5k as wiznet5k
 import adafruit_wiznet5k.adafruit_wiznet5k_socket as socket
 
-_the_interface = None  # pylint: disable=invalid-name
+_the_interface: Optional[WIZNET5K] = None  # pylint: disable=invalid-name
 
 
-def set_interface(iface):
-    """Helper to set the global internet interface"""
+def set_interface(iface: WIZNET5K) -> None:
+    """
+    Helper to set the global internet interface.
+
+    :param wiznet5k.adafruit_wiznet5k.WIZNET5K: Ethernet interface.
+    """
     global _the_interface  # pylint: disable=global-statement, invalid-name
     _the_interface = iface
     socket.set_interface(iface)
@@ -46,11 +59,19 @@ def set_interface(iface):
 
 # pylint: disable=invalid-name
 class WSGIServer:
-    """
-    A simple server that implements the WSGI interface
-    """
+    """A simple server that implements the WSGI interface."""
 
-    def __init__(self, port=80, debug=False, application=None):
+    def __init__(
+        self,
+        port: int = 80,
+        debug: bool = False,
+        application: Optional[callable] = None,
+    ) -> None:
+        """
+        :param int port: WSGI server port, defaults to 80.
+        :param bool debug: Enable debugging, defaults to False.
+        :param Optional[callable] application: Application to call in response to a HTTP request.
+        """
         self.application = application
         self.port = port
         self._timeout = 20
@@ -66,9 +87,10 @@ class WSGIServer:
         if self._debug:
             print("Max sockets: ", self.MAX_SOCK_NUM)
 
-    def start(self):
+    def start(self) -> None:
         """
-        Starts the server and begins listening for incoming connections.
+        Start the server and listen for incoming connections.
+
         Call update_poll in the main loop for the application callable to be
         invoked on receiving an incoming request.
         """
@@ -82,8 +104,10 @@ class WSGIServer:
             ip = _the_interface.pretty_ip(_the_interface.ip_address)
             print("Server available at {0}:{1}".format(ip, self.port))
 
-    def update_poll(self):
+    def update_poll(self) -> None:
         """
+        Check for new incoming client requests.
+
         Call this method inside your main event loop to get the server
         check for new incoming client requests. When a request comes in,
         the application callable will be invoked.
@@ -108,14 +132,14 @@ class WSGIServer:
             except RuntimeError:
                 pass
 
-    def finish_response(self, result, client):
+    def finish_response(self, result: str, client: socket.socket) -> None:
         """
         Called after the application callable returns result data to respond with.
         Creates the HTTP Response payload from the response_headers and results data,
         and sends it back to client.
 
-        :param string result: the data string to send back in the response to the client.
-        :param Socket client: the socket to send the response to.
+        :param str result: the data string to send back in the response to the client.
+        :param socket.socket client: the socket to send the response to.
         """
         try:
             response = "HTTP/1.1 {0}\r\n".format(self._response_status)
@@ -140,25 +164,29 @@ class WSGIServer:
             client.disconnect()
             client.close()
 
-    def _start_response(self, status, response_headers):
+    def _start_response(
+        self, status: str, response_headers: List[Tuple[str, str]]
+    ) -> None:
         """
         The application callable will be given this method as the second param
         This is to be called before the application callable returns, to signify
         the response can be started with the given status and headers.
 
-        :param string status: a status string including the code and reason. ex: "200 OK"
-        :param list response_headers: a list of tuples to represent the headers.
+        :param str status: a status string including the code and reason. ex: "200 OK"
+        :param List[Tuple[str, str]] response_headers: a list of tuples to represent the headers.
             ex ("header-name", "header value")
         """
         self._response_status = status
         self._response_headers = [("Server", "w5kWSGIServer")] + response_headers
 
-    def _get_environ(self, client):
+    def _get_environ(self, client: socket.socket) -> Dict:
         """
         The application callable will be given the resulting environ dictionary.
         It contains metadata about the incoming request and the request body ("wsgi.input")
 
-        :param Socket client: socket to read the request from
+        :param socket.socket client: Socket to read the request from.
+
+        :return Dict: Data for the application callable.
         """
         env = {}
         line = str(client.readline(), "utf-8")
